@@ -41,7 +41,7 @@ use Exception::Class (
 	},
 );
 
-our $VERSION = '2.13';
+our $VERSION = '2.14';
 
 sub set_time {
 	my ( $self, %conf ) = @_;
@@ -890,11 +890,13 @@ sub get_efa_urls {
 			name      => 'Vorarlberger Verkehrsverbund',
 			shortname => 'VVV',
 		},
-		{
-			url  => 'http://fahrplan.verbundlinie.at/stv/XSLT_TRIP_REQUEST2',
-			name => 'Verkehrsverbund Steiermark',
-			shortname => 'Verbundlinie',
-		},
+
+		# Returns broken Unicode which makes Encode::decode die()
+		#{
+		#	url  => 'http://fahrplan.verbundlinie.at/stv/XSLT_TRIP_REQUEST2',
+		#	name => 'Verkehrsverbund Steiermark',
+		#	shortname => 'Verbundlinie',
+		#},
 		{
 			url       => 'http://www.linzag.at/static/XSLT_TRIP_REQUEST2',
 			name      => 'Linz AG',
@@ -920,6 +922,42 @@ sub get_efa_urls {
 			name      => 'Verkehrsverbund Stuttgart',
 			shortname => 'VVS',
 		},
+		{
+			url => 'http://delfi1.vvo-online.de:8080/delfi3/XSLT_TRIP_REQUEST2',
+			name      => 'Verkehrsverbund Oberelbe',
+			shortname => 'VVO',
+		},
+		{
+			url       => 'http://delfi.vrn.de/delfi/XSLT_TRIP_REQUEST2',
+			name      => 'Verkehrsverbund Rhein-Neckar (DELFI)',
+			shortname => 'VRNdelfi',
+		},
+		{
+			url  => 'http://fahrplanauskunft.vrn.de/vrn/XSLT_TRIP_REQUEST2',
+			name => 'Verkehrsverbund Rhein-Neckar',
+			shortname => 'VRN',
+		},
+		{
+			url       => 'http://80.146.180.107/vmv/XSLT_TRIP_REQUEST2',
+			name      => 'Verkehrsgesellschaft Mecklenburg-Vorpommern',
+			shortname => 'VMV',
+		},
+		{
+			url       => 'http://213.144.24.66/kvv2/XML_TRIP_REQUEST2',
+			name      => 'Karlsruher Verkehrsverbund',
+			shortname => 'KVV',
+		},
+		{
+			url =>
+			  'http://www.travelineeastmidlands.co.uk/em/XSLT_TRIP_REQUEST2',
+			name      => 'Traveline East Midlands',
+			shortname => 'TLEM',
+		},
+		{
+			url       => 'http://mobil.vbl.ch/vblmobil/XML_TRIP_REQUEST2',
+			name      => 'Verkehrsbetriebe Luzern',
+			shortname => 'VBL',
+		},
 	);
 }
 
@@ -955,7 +993,7 @@ Travel::Routing::DE::EFA - unofficial interface to EFA-based itinerary services
 
 =head1 VERSION
 
-version 2.13
+version 2.14
 
 =head1 DESCRIPTION
 
@@ -999,10 +1037,11 @@ is not completely supported yet and may not work at all.
 
 =item * L<http://efaneu.vmobil.at/vvv/XSLT_TRIP_REQUEST2> (Vorarlberger Verkehrsverbund)
 
-=item * L<http://fahrplan.verbundlinie.at/stv/XSLT_TRIP_REQUEST2> (Verkehrsverbund Steiermark) B<[!]>
-
 =item * L<http://www.linzag.at/static/XSLT_TRIP_REQUEST2> (Linz AG) B<[!]>
 
+=item * The STV / Verkehrsverbund Steiermark is not supported since it returns
+data with broken encoding
+
 =back
 
 =item * Germany
